;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "citre" "20251015.220"
  "Superior code reading & auto-completion tool with pluggable backends."
  '((emacs "26.1"))
  :url "https://github.com/universal-ctags/citre"
  :commit "300596a34b61b486530ce3759e8fb722d9534325"
  :revdesc "300596a34b61"
  :keywords '("convenience" "tools")
  :authors '(("Hao Wang" . "amaikinono@gmail.com"))
  :maintainers '(("Hao Wang" . "amaikinono@gmail.com")))
